"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _awsSdk = require("aws-sdk");

var _bluebird = _interopRequireDefault(require("bluebird"));

/* eslint import/no-extraneous-dependencies: ["error", {"devDependencies": true}] */
_awsSdk.config.setPromisesDependency(_bluebird.default);

class Connector {
  constructor({
    debug,
    streamName = process.env.STREAM_NAME,
    timeout = Number(process.env.KINESIS_TIMEOUT) || Number(process.env.TIMEOUT) || 1000
  }) {
    this.debug = msg => debug('%j', msg);

    this.streamName = streamName || 'undefined';
    this.stream = new _awsSdk.Kinesis({
      httpOptions: {
        timeout
      },
      logger: {
        log:
        /* istanbul ignore next */
        msg => debug('%s', msg.replace(/\n/g, '\r'))
      }
    });
  }

  putRecords(inputParams) {
    const params = {
      StreamName: this.streamName,
      ...inputParams
    };
    return this.stream.putRecords(params).promise().tap(this.debug).tapCatch(this.debug);
  }

}

var _default = Connector;
exports.default = _default;